@@ -948,7 +948,7 @@ class DataFieldBase(FieldBase, metaclass=ABCMeta):
 
         Args:
             method (str):
-                The method used for interpolation. Currently, 'linear' and 'nearest' are
+                The method used for interpolation. Currently, "linear" and "nearest" are
                 supported by :class:`~scipy.interpolate.RegularGridInterpolator`.
             fill (Number, optional):
                 Determines how values out of bounds are handled. If `None`, a
@@ -1115,8 +1115,8 @@ class DataFieldBase(FieldBase, metaclass=ABCMeta):
                 used for the interpolation.
             method (str):
                 Determines the method being used for interpolation. Typical values that
-                are `nearest` and `linear, but the supported values depend on the chosen
-                `backend.
+                are "nearest" and "linear", but the supported values depend on the
+                chosen `backend`.
             fill (Number, optional):
                 Determines how values out of bounds are handled. If `None`, a
                 `ValueError` is raised when out-of-bounds points are requested.
@@ -1168,12 +1168,12 @@ class DataFieldBase(FieldBase, metaclass=ABCMeta):
                 The points at which the values should be obtained. This is given in grid
                 coordinates.
             backend (str):
-                The accepted values `scipy` and `numba` determine the backend that is
+                The accepted values "scipy" and "numba" determine the backend that is
                 used for the interpolation.
             method (str):
                 Determines the method being used for interpolation. Typical values that
-                are `nearest` and `linear, but the supported values depend on the chosen
-                `backend.
+                are "nearest" and "linear", but the supported values depend on the
+                chosen `backend`.
             fill (Number, optional):
                 Determines how values out of bounds are handled. If `None`, a
                 `ValueError` is raised when out-of-bounds points are requested.
@@ -1206,12 +1206,12 @@ class DataFieldBase(FieldBase, metaclass=ABCMeta):
                 The grid of the new field onto which the current field is
                 interpolated.
             backend (str):
-                The accepted values `scipy` and `numba` determine the backend that is
+                The accepted values "scipy" and "numba" determine the backend that is
                 used for the interpolation.
             method (str):
                 Determines the method being used for interpolation. Typical values that
-                are `nearest` and `linear, but the supported values depend on the chosen
-                `backend.
+                are "nearest" and "linear", but the supported values depend on the
+                chosen `backend`.
             fill (Number, optional):
                 Determines how values out of bounds are handled. If `None`, a
                 `ValueError` is raised when out-of-bounds points are requested.
