@@ -314,7 +314,7 @@ class SphericalGridBase(GridBase, metaclass=ABCMeta):  # lgtm [py/missing-equals
             :class:`~numpy.ndarray`: Points given in the coordinates of the grid
         """
         points = np.atleast_1d(points)
-        assert points.shape[-1] == self.dim
+        assert points.shape[-1] == self.dim, f"Point must have {self.dim} coordinates"
         return np.linalg.norm(points, axis=-1, keepdims=True)  # type: ignore
 
     def cell_to_point(self, cells: np.ndarray, cartesian: bool = True) -> np.ndarray:
@@ -336,7 +336,7 @@ class SphericalGridBase(GridBase, metaclass=ABCMeta):  # lgtm [py/missing-equals
             :class:`~numpy.ndarray`: The center points of the respective cells
         """
         cells = np.atleast_1d(cells)
-        assert cells.shape[-1] == self.num_axes
+        assert cells.shape[-1] == self.num_axes, f"Require {self.num_axes} coordinates"
 
         # convert from cells indices to grid coordinates
         r_inner, _ = self.axes_bounds[0]
@@ -376,7 +376,9 @@ class SphericalGridBase(GridBase, metaclass=ABCMeta):  # lgtm [py/missing-equals
         """
         return np.atleast_1d(p2) - np.atleast_1d(p1)  # type: ignore
 
-    def polar_coordinates_real(self, origin=None, *, ret_angle: bool = False, **kwargs):
+    def polar_coordinates_real(
+        self, origin=None, *, ret_angle: bool = False, **kwargs
+    ) -> Union[np.ndarray, Tuple[np.ndarray, ...]]:
         """return spherical coordinates associated with the grid
 
         Args:
@@ -397,7 +399,7 @@ class SphericalGridBase(GridBase, metaclass=ABCMeta):  # lgtm [py/missing-equals
         # the distance to the origin is exactly the radial coordinate
         rs = self.axes_coords[0]
         if ret_angle:
-            return rs, (np.zeros_like(rs),) * (self.dim - 1)
+            return (rs,) + (np.zeros_like(rs),) * (self.dim - 1)
         else:
             return rs
 
