@@ -90,13 +90,16 @@ class WavePDE(PDEBase):
             :class:`~pde.fields.FieldCollection`:
             Scalar field describing the evolution rate of the PDE
         """
-        assert isinstance(state, FieldCollection)
+        assert isinstance(state, FieldCollection), "`state` must be FieldCollection"
+        assert len(state) == 2, "`state` must contain two fields"
         u, v = state
         u_t = v.copy()
         v_t = self.speed ** 2 * u.laplace(self.bc)  # type: ignore
         return FieldCollection([u_t, v_t])
 
-    def _make_pde_rhs_numba(self, state: FieldCollection) -> Callable:  # type: ignore
+    def _make_pde_rhs_numba(  # type: ignore
+        self, state: FieldCollection
+    ) -> Callable[[np.ndarray, float], np.ndarray]:
         """create a compiled function evaluating the right hand side of the PDE
 
         Args:
