@@ -152,7 +152,6 @@ class Controller:
         self.info["solver_start"] = str(solver_start)
         profiler = {"solver": 0.0, "tracker": 0.0}
         self.info["profiler"] = profiler
-        prof_start_tracker = time.process_time()
 
         # add some tolerance to account for inaccurate float point math
         if dt is None:
@@ -170,18 +169,16 @@ class Controller:
         try:
             while t < t_end:
                 # determine next time point with an action
+                prof_start_tracker = time.process_time()
                 t_next_action = self.trackers.handle(state, t, atol=atol)
+                profiler["tracker"] += time.process_time() - prof_start_tracker
                 t_next_action = max(t_next_action, t + atol)
                 t_break = min(t_next_action, t_end)
 
-                prof_start_solve = time.process_time()
-                profiler["tracker"] += prof_start_solve - prof_start_tracker
-
                 # advance the system to the new time point
+                prof_start_solve = time.process_time()
                 t = stepper(state, t, t_break)
-
-                prof_start_tracker = time.process_time()
-                profiler["solver"] += prof_start_tracker - prof_start_solve
+                profiler["solver"] += time.process_time() - prof_start_solve
 
         except StopIteration as err:
             # iteration has been interrupted by a tracker
@@ -203,13 +200,14 @@ class Controller:
 
             # handle trackers one more time when t_end is reached
             try:
+                prof_start_tracker = time.process_time()
                 self.trackers.handle(state, t, atol=atol)
+                profiler["tracker"] += time.process_time() - prof_start_tracker
             except StopIteration as err:
                 # error detected in the final handling of the tracker
                 msg_level, msg = _handle_stop_iteration(err)
 
         # calculate final statistics
-        profiler["tracker"] += time.process_time() - prof_start_tracker
         duration = datetime.datetime.now() - solver_start
         self.info["solver_duration"] = str(duration)
         self.info["t_final"] = t
